@@ -8,15 +8,11 @@ import jsii
 import publication
 import typing_extensions
 
-import aws_cdk.aws_iam._jsii
-import aws_cdk.aws_lambda._jsii
-import aws_cdk.aws_logs._jsii
-import aws_cdk.core._jsii
-import aws_cdk.custom_resources._jsii
+import aws_cdk._jsii
 import constructs._jsii
 
 __jsii_assembly__ = jsii.JSIIAssembly.load(
-    "cdk-lambda-bash", "0.5.181", __name__[0:-6], "cdk-lambda-bash@0.5.181.jsii.tgz"
+    "cdk-lambda-bash", "2.0.0", __name__[0:-6], "cdk-lambda-bash@2.0.0.jsii.tgz"
 )
 
 __all__ = [
